@@ -6,6 +6,7 @@
 #include <thread>
 
 #include "coeurl/request.hpp"
+#include "coeurl/errors.hpp"
 
 namespace coeurl {
 std::shared_ptr<spdlog::logger> Client::log = spdlog::null_logger_mt("coeurl_null");
@@ -133,21 +134,16 @@ void Client::cancel_requests_cb(evutil_socket_t, short, void *userp) {
 
     Client *g = (Client *)userp;
 
-        // prevent new requests from being added
-        {
-            g->prevent_new_requests = true;
-        }
+    // prevent new requests from being added
+    { g->prevent_new_requests = true; }
 
-        // safe to access now, since we are running on the worker thread and only
-        // there running_requests is modified
-        while (!g->running_requests.empty())
-            g->remove_request(g->running_requests.back().get());
-
-        // Allow for new requests
-        {
-            g->prevent_new_requests = false;
-        }
+    // safe to access now, since we are running on the worker thread and only
+    // there running_requests is modified
+    while (!g->running_requests.empty())
+        g->remove_request(g->running_requests.back().get());
 
+    // Allow for new requests
+    { g->prevent_new_requests = false; }
 
     CURLMcode rc = curl_multi_socket_action(g->multi, CURL_SOCKET_TIMEOUT, 0, &g->still_running);
     mcode_or_die("timer_cb: curl_multi_socket_action", rc);
@@ -352,7 +348,7 @@ void Client::remove_request(Request *r) {
         long http_code;
         curl_easy_getinfo(req->easy, CURLINFO_RESPONSE_CODE, &http_code);
 
-        Client::log->trace("DONE: {} => {} ({}) http: {}", req->url_, req->curl_error, req->error, http_code);
+        Client::log->trace("DONE: {} => {} ({}) http: {}", req->url_, coeurl::to_string(req->curl_error), req->error, http_code);
 
         if (req->on_complete_)
             req->on_complete_(*req.get());
@@ -393,8 +389,8 @@ void Client::delete_(std::string url, std::function<void(const Request &)> callb
     this->submit_request(std::move(req));
 }
 
-void Client::delete_(std::string url, std::string request_body, std::string mimetype, std::function<void(const Request &)> callback, const Headers &headers,
-                     long max_redirects) {
+void Client::delete_(std::string url, std::string request_body, std::string mimetype,
+                     std::function<void(const Request &)> callback, const Headers &headers, long max_redirects) {
     auto req = std::make_shared<Request>(this, Request::Method::Delete, std::move(url));
 
     req->request(request_body, mimetype);
